pub(super) fn make_mutable<T: HashConsable>(
x: &mut HashConsed<T>,
) -> impl DerefMut<Target = T>Expand description
The returned value must not be leaked as this would break the hash-consing invariant.
pub(super) fn make_mutable<T: HashConsable>(
x: &mut HashConsed<T>,
) -> impl DerefMut<Target = T>The returned value must not be leaked as this would break the hash-consing invariant.